@@ -4,5 +4,6 @@
   packageStartupMessage(paste0("Package: ", pkgname, ", Version: ", RFver))
   packageStartupMessage("Stochastic Newton Sampler for log-concave probability densities.")
   #packageStartupMessage("Metropolis-Hastings sampling of log-concave probability densities using the Stochastic Newton Sampler.")
-  packageStartupMessage("Scientific Computing Group, Sentrana Inc.")
+  packageStartupMessage("Scientific Computing Group, Sentrana Inc. &")
+  packageStartupMessage("Imperial College London")
 }
